==> ring_20190822.1.aaa3449.tar.gz: ring-project/lrc/translations/lrc_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" sourcelanguage="en" version="2.0">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/qtwrapper/callmanager_wrap.h" line="315"/>
        <source>Me</source>
        <translation>Eu</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="60"/>
        <source>Hold</source>
        <translation>Modo de espera</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="62"/>
        <source>Talking</source>
        <translation>A falar</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="64"/>
        <source>ERROR</source>
        <translation>ERRO</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="66"/>
        <source>Incoming</source>
        <translation>A receber</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="68"/>
        <source>Calling</source>
        <translation>A chamar</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="70"/>
        <source>Connecting</source>
        <translation>A conectar</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="72"/>
        <source>Searching</source>
        <translation>A pesquisar</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="74"/>
        <source>Inactive</source>
        <translation>Inativo</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="76"/>
        <location filename="../src/api/call.h" line="82"/>
        <source>Finished</source>
        <translation>Terminado</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="78"/>
        <source>Timeout</source>
        <translation>Tempo limite excedido</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="80"/>
        <source>Peer busy</source>
        <translation>Contacto ocupado</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="84"/>
        <source>Communication established</source>
        <translation>Comunicação estabelecida</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1272"/>
        <location filename="../src/conversationmodel.cpp" line="1661"/>
        <location filename="../src/conversationmodel.cpp" line="1924"/>
        <source>Invitation received</source>
        <translation>Convite recebido</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1273"/>
        <source>Contact added</source>
        <translation>Contacto adicionado</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1315"/>
        <location filename="../src/conversationmodel.cpp" line="1322"/>
        <source>Invitation accepted</source>
        <translation>Convite aceite</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1532"/>
        <source>ð Outgoing call</source>
        <translation>ð Chamada feita</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1534"/>
        <source>ð Incoming call</source>
        <translation>ð Chamada recebida</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1547"/>
        <source>ð Outgoing call - </source>
        <translation>ð Chamada feita - </translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1550"/>
        <source>ð Incoming call - </source>
        <translation>ð Chamada recebida - </translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1554"/>
        <source>ð½ Missed outgoing call</source>
        <translation>ð½ Chamada feita não atendida</translation>
    </message>
    <message>
        <location filename="../src/conversationmodel.cpp" line="1556"/>
        <source>ð½ Missed incoming call</source>
        <translation>ð½ Chamada recebida não atendida</translation>
    </message>
    <message>
        <location filename="../src/avmodel.cpp" line="311"/>
        <location filename="../src/avmodel.cpp" line="332"/>
        <source>default</source>
        <translation>padrão</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="45"/>
        <source>Null</source>
        <translation>Nulo</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="46"/>
        <source>Trying</source>
        <translation>A tentar</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="47"/>
        <source>Ringing</source>
        <translation>A tocar</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="48"/>
        <source>Being Forwarded</source>
        <translation>A ser reencaminhado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="49"/>
        <source>Queued</source>
        <translation>Na fila</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="50"/>
        <source>Progress</source>
        <translation>A decorrer</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="51"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="52"/>
        <source>Accepted</source>
        <translation>Aceite</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="53"/>
        <source>Multiple Choices</source>
        <translation>Várias escolhas</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="54"/>
        <source>Moved Permanently</source>
        <translation>Movido permanentemente</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="55"/>
        <source>Moved Temporarily</source>
        <translation>Movido temporariamente</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="56"/>
        <source>Use Proxy</source>
        <translation>Usar proxy</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="57"/>
        <source>Alternative Service</source>
        <translation>Serviço alternativo</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="58"/>
        <source>Bad Request</source>
        <translation>Pedido inválido</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="59"/>
        <source>Unauthorized</source>
        <translation>Não autorizado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="60"/>
        <source>Payment Required</source>
        <translation>Necessário pagamento</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="61"/>
        <source>Forbidden</source>
        <translation>Proibido</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="62"/>
        <source>Not Found</source>
        <translation>Não encontrado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="63"/>
        <source>Method Not Allowed</source>
        <translation>Método não permitido</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="64"/>
        <location filename="../src/newcallmodel.cpp" line="84"/>
        <source>Not Acceptable</source>
        <translation>Não aceitável</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="65"/>
        <source>Proxy Authentication Required</source>
        <translation>Necessário autenticação de proxy</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="66"/>
        <source>Request Timeout</source>
        <translation>O pedido excedeu o tempo limite</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="67"/>
        <source>Gone</source>
        <translation>Foi-se</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="68"/>
        <source>Request Entity Too Large</source>
        <translation>Entidade do pedido demasiado grande</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="69"/>
        <source>Request URI Too Long</source>
        <translation>URI de pedido demasiado longo</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="70"/>
        <source>Unsupported Media Type</source>
        <translation>Tipo de media não suportado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="71"/>
        <source>Unsupported URI Scheme</source>
        <translation>Esquema URI não suportado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="72"/>
        <source>Bad Extension</source>
        <translation>Extensão inválida</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="73"/>
        <source>Extension Required</source>
        <translation>Necessária extensão</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="74"/>
        <source>Session Timer Too Small</source>
        <translation>Temporizador de sessão demasiado pequeno</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="75"/>
        <source>Interval Too Brief</source>
        <translation>Intervalo demasiado breve</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="76"/>
        <source>Temporarily Unavailable</source>
        <translation>Não disponível temporariamente</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="77"/>
        <source>Call TSX Does Not Exist</source>
        <translation> A chamada TSX não existe</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="78"/>
        <source>Loop Detected</source>
        <translation>Detetado loop</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="79"/>
        <source>Too Many Hops</source>
        <translation>Demasiados saltos</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="80"/>
        <source>Address Incomplete</source>
        <translation>Endereço incompleto</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="81"/>
        <source>Ambiguous</source>
        <translation>Ambíguo</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="82"/>
        <source>Busy</source>
        <translation>Ocupado(a)</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="83"/>
        <source>Request Terminated</source>
        <translation>Pedido terminado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="85"/>
        <source>Bad Event</source>
        <translation>Evento inválido</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="86"/>
        <source>Request Updated</source>
        <translation>Pedido atualizado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="87"/>
        <source>Request Pending</source>
        <translation>Pedido pendente</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="88"/>
        <source>Undecipherable</source>
        <translation>Não decifrável</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="89"/>
        <source>Internal Server Error</source>
        <translation>Erro interno do servidor</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="90"/>
        <source>Not Implemented</source>
        <translation>Não implementado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="91"/>
        <source>Bad Gateway</source>
        <translation>Gateway inválido</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="92"/>
        <source>Service Unavailable</source>
        <translation>Serviço indisponível</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="93"/>
        <source>Server Timeout</source>
        <translation>Tempo de resposta do servidor excedido</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="94"/>
        <source>Version Not Supported</source>
        <translation>Versão não suportada</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="95"/>
        <source>Message Too Large</source>
        <translation>Mensagem demasiado grande</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="96"/>
        <source>Precondition Failure</source>
        <translation>Falha nos pré-requisitos</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="97"/>
        <source>Busy Everywhere</source>
        <translation>Ocupado em todo o lado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="98"/>
        <source>Call Refused</source>
        <translation>Chamada recusada</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="99"/>
        <source>Does Not Exist Anywhere</source>
        <translation>Não existe em lugar nenhum</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="100"/>
        <source>Not Acceptable Anywhere</source>
        <translation>Não aceite em lugar nenhum</translation>
    </message>
</context>
<context>
    <name>lrc::ContactModelPimpl</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="403"/>
        <source>Searchingâ¦</source>
        <translation>A pesquisar</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="760"/>
        <source>Invalid ID</source>
        <translation>ID inválido</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="763"/>
        <source>Not found</source>
        <translation>Não encontrado</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="766"/>
        <source>Couldn&apos;t lookupâ¦</source>
        <translation>Não foi possível procurar</translation>
    </message>
</context>
<context>
    <name>lrc::api::ContactModel</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="374"/>
        <source>Bad URI scheme</source>
        <translation>Mau esquema de URI</translation>
    </message>
</context>
</TS>

==> ring_20191025.1.074a237.tar.gz: ring-project/lrc/translations/lrc_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" sourcelanguage="en" version="2.0">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/qtwrapper/callmanager_wrap.h" line="315"/>
        <source>Me</source>
        <translation>Eu</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="60"/>
        <source>Hold</source>
        <translation>Modo de espera</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="62"/>
        <source>Talking</source>
        <translation>A falar</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="64"/>
        <source>ERROR</source>
        <translation>ERRO</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="66"/>
        <source>Incoming</source>
        <translation>A receber</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="68"/>
        <source>Calling</source>
        <translation>A chamar</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="70"/>
        <source>Connecting</source>
        <translation>A conectar</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="72"/>
        <source>Searching</source>
        <translation>A pesquisar</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="74"/>
        <source>Inactive</source>
        <translation>Inativo</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="76"/>
        <location filename="../src/api/call.h" line="82"/>
        <source>Finished</source>
        <translation>Terminado</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="78"/>
        <source>Timeout</source>
        <translation>Tempo limite excedido</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="80"/>
        <source>Peer busy</source>
        <translation>Contacto ocupado</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="84"/>
        <source>Communication established</source>
        <translation>Comunicação estabelecida</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="135"/>
        <location filename="../src/authority/storagehelper.cpp" line="856"/>
        <source>Invitation received</source>
        <translation>Convite recebido</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="132"/>
        <location filename="../src/authority/storagehelper.cpp" line="854"/>
        <source>Contact added</source>
        <translation>Contacto adicionado</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="106"/>
        <location filename="../src/authority/storagehelper.cpp" line="112"/>
        <location filename="../src/authority/storagehelper.cpp" line="852"/>
        <source>Outgoing call</source>
        <translation>Chamada efetuada</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="108"/>
        <location filename="../src/authority/storagehelper.cpp" line="119"/>
        <source>Incoming call</source>
        <translation>Chamada recebida</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="115"/>
        <location filename="../src/authority/storagehelper.cpp" line="850"/>
        <source>Missed outgoing call</source>
        <translation>Chamadas efetuadas perdidas</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="122"/>
        <source>Missed incoming call</source>
        <translation>Chamadas recebidas perdidas</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="137"/>
        <location filename="../src/authority/storagehelper.cpp" line="858"/>
        <source>Invitation accepted</source>
        <translation>Convite aceite</translation>
    </message>
    <message>
        <location filename="../src/avmodel.cpp" line="312"/>
        <location filename="../src/avmodel.cpp" line="333"/>
        <source>default</source>
        <translation>padrão</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="48"/>
        <source>Null</source>
        <translation>Nulo</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="49"/>
        <source>Trying</source>
        <translation>A tentar</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="50"/>
        <source>Ringing</source>
        <translation>A tocar</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="51"/>
        <source>Being Forwarded</source>
        <translation>A ser reencaminhado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="52"/>
        <source>Queued</source>
        <translation>Na fila</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="53"/>
        <source>Progress</source>
        <translation>A decorrer</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="54"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="55"/>
        <source>Accepted</source>
        <translation>Aceite</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="56"/>
        <source>Multiple Choices</source>
        <translation>Várias escolhas</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="57"/>
        <source>Moved Permanently</source>
        <translation>Movido permanentemente</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="58"/>
        <source>Moved Temporarily</source>
        <translation>Movido temporariamente</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="59"/>
        <source>Use Proxy</source>
        <translation>Usar proxy</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="60"/>
        <source>Alternative Service</source>
        <translation>Serviço alternativo</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="61"/>
        <source>Bad Request</source>
        <translation>Pedido inválido</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="62"/>
        <source>Unauthorized</source>
        <translation>Não autorizado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="63"/>
        <source>Payment Required</source>
        <translation>Necessário pagamento</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="64"/>
        <source>Forbidden</source>
        <translation>Proibido</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="65"/>
        <source>Not Found</source>
        <translation>Não encontrado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="66"/>
        <source>Method Not Allowed</source>
        <translation>Método não permitido</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="67"/>
        <location filename="../src/newcallmodel.cpp" line="87"/>
        <source>Not Acceptable</source>
        <translation>Não aceitável</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="68"/>
        <source>Proxy Authentication Required</source>
        <translation>Necessário autenticação de proxy</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="69"/>
        <source>Request Timeout</source>
        <translation>O pedido excedeu o tempo limite</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="70"/>
        <source>Gone</source>
        <translation>Foi-se</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="71"/>
        <source>Request Entity Too Large</source>
        <translation>Entidade do pedido demasiado grande</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="72"/>
        <source>Request URI Too Long</source>
        <translation>URI de pedido demasiado longo</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="73"/>
        <source>Unsupported Media Type</source>
        <translation>Tipo de media não suportado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="74"/>
        <source>Unsupported URI Scheme</source>
        <translation>Esquema URI não suportado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="75"/>
        <source>Bad Extension</source>
        <translation>Extensão inválida</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="76"/>
        <source>Extension Required</source>
        <translation>Necessária extensão</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="77"/>
        <source>Session Timer Too Small</source>
        <translation>Temporizador de sessão demasiado pequeno</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="78"/>
        <source>Interval Too Brief</source>
        <translation>Intervalo demasiado breve</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="79"/>
        <source>Temporarily Unavailable</source>
        <translation>Não disponível temporariamente</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="80"/>
        <source>Call TSX Does Not Exist</source>
        <translation> A chamada TSX não existe</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="81"/>
        <source>Loop Detected</source>
        <translation>Detetado loop</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="82"/>
        <source>Too Many Hops</source>
        <translation>Demasiados saltos</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="83"/>
        <source>Address Incomplete</source>
        <translation>Endereço incompleto</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="84"/>
        <source>Ambiguous</source>
        <translation>Ambíguo</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="85"/>
        <source>Busy</source>
        <translation>Ocupado(a)</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="86"/>
        <source>Request Terminated</source>
        <translation>Pedido terminado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="88"/>
        <source>Bad Event</source>
        <translation>Evento inválido</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="89"/>
        <source>Request Updated</source>
        <translation>Pedido atualizado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="90"/>
        <source>Request Pending</source>
        <translation>Pedido pendente</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="91"/>
        <source>Undecipherable</source>
        <translation>Não decifrável</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="92"/>
        <source>Internal Server Error</source>
        <translation>Erro interno do servidor</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="93"/>
        <source>Not Implemented</source>
        <translation>Não implementado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="94"/>
        <source>Bad Gateway</source>
        <translation>Gateway inválido</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="95"/>
        <source>Service Unavailable</source>
        <translation>Serviço indisponível</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="96"/>
        <source>Server Timeout</source>
        <translation>Tempo de resposta do servidor excedido</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="97"/>
        <source>Version Not Supported</source>
        <translation>Versão não suportada</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="98"/>
        <source>Message Too Large</source>
        <translation>Mensagem demasiado grande</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="99"/>
        <source>Precondition Failure</source>
        <translation>Falha nos pré-requisitos</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="100"/>
        <source>Busy Everywhere</source>
        <translation>Ocupado em todo o lado</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="101"/>
        <source>Call Refused</source>
        <translation>Chamada recusada</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="102"/>
        <source>Does Not Exist Anywhere</source>
        <translation>Não existe em lugar nenhum</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="103"/>
        <source>Not Acceptable Anywhere</source>
        <translation>Não aceite em lugar nenhum</translation>
    </message>
</context>
<context>
    <name>lrc::ContactModelPimpl</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="405"/>
        <source>Searchingâ¦</source>
        <translation>A pesquisar</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="765"/>
        <source>Invalid ID</source>
        <translation>ID inválido</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="768"/>
        <source>Registered name not found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="771"/>
        <source>Couldn&apos;t lookupâ¦</source>
        <translation>Não foi possível procurar</translation>
    </message>
</context>
<context>
    <name>lrc::api::ContactModel</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="371"/>
        <source>Bad URI scheme</source>
        <translation>Mau esquema de URI</translation>
    </message>
</context>
</TS>
